@@ -10,15 +10,17 @@ class.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "23-07-2020"
-__version__ = "0.2.1"
+__date__ = "27-08-2020"
+__version__ = "0.2.3"
 # pylint: disable=bare-except, broad-except, try-except-raise
 
 import sys
 import time
-from typing import Union, Callable
+from typing import AnyStr, Callable
 from pathlib import Path
-from ast import literal_eval
+
+# Use of `ast.literal_eval` got removed in v0.2.2 because it chokes on `nan`
+# from ast import literal_eval
 
 import serial
 import serial.tools.list_ports
@@ -124,7 +126,7 @@ class SerialDevice:
     # --------------------------------------------------------------------------
 
     def set_read_termination(
-        self, termination: Union[str, bytes], query_wait_time: float = 0.1,
+        self, termination: AnyStr, query_wait_time: float = 0.1,
     ):
         """Set the termination character(s) for serial read.
 
@@ -155,7 +157,7 @@ class SerialDevice:
     #   set_write_termination
     # --------------------------------------------------------------------------
 
-    def set_write_termination(self, termination: Union[str, bytes, None]):
+    def set_write_termination(self, termination: AnyStr):
         """Set the termination character(s) for serial write.
 
         Args:
@@ -263,7 +265,7 @@ class SerialDevice:
     #   write
     # --------------------------------------------------------------------------
 
-    def write(self, msg, raises_on_timeout: bool = False) -> bool:
+    def write(self, msg: AnyStr, raises_on_timeout: bool = False) -> bool:
         """Send a message to the serial device.
 
         Args:
@@ -305,7 +307,7 @@ class SerialDevice:
 
     def query(
         self,
-        msg: Union[str, bytes],
+        msg: AnyStr,
         raises_on_timeout: bool = False,
         returns_ascii: bool = True,
     ) -> tuple:
@@ -431,7 +433,10 @@ class SerialDevice:
             return (False, ())  # --> leaving
 
         try:
-            reply_list = list(map(literal_eval, reply.split(delimiter)))
+            # NOTE: `ast.literal_eval` chokes when it receives 'nan' so we ditch
+            # it and just interpret everything as `float` instead.
+            # reply_list = list(map(literal_eval, reply.split(delimiter)))
+            reply_list = list(map(float, reply.split(delimiter)))
         except ValueError as err:
             pft(err, 3)
             return (False, ())  # --> leaving
