@@ -6,7 +6,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "15-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.3"
 # pylint: disable=bare-except
 
 import sys
@@ -15,7 +15,7 @@ from pathlib import Path
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
-from dvg_utils.dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY, SS_GROUP
+from dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY, SS_GROUP
 
 from dvg_devices.Compax3_servo_protocol_RS232 import Compax3_servo
 from dvg_devices.Compax3_servo_qdev import Compax3_servo_qdev
