@@ -15,7 +15,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "06-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.3"
 # pylint: disable=try-except-raise
 
 import sys
@@ -25,7 +25,7 @@ from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
 from dvg_debug_functions import print_fancy_traceback as pft
-from dvg_utils.dvg_pyqt_controls import create_Toggle_button, SS_GROUP
+from dvg_pyqt_controls import create_Toggle_button, SS_GROUP
 
 from dvg_devices.Compax3_servo_protocol_RS232 import Compax3_servo
 
