@@ -11,13 +11,13 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "23-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.3"
 # pylint: disable=broad-except
 
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
-from dvg_utils.dvg_pyqt_controls import (
+from dvg_pyqt_controls import (
     create_Toggle_button,
     SS_TEXTBOX_ERRORS,
     SS_TEXTBOX_READ_ONLY,
@@ -335,7 +335,7 @@ class Keysight_3497xA_qdev(QDeviceIO):
         self.qtbl_readings.setFont(FONT_MONOSPACE_SMALL)
         # self.qtbl_readings.setMinimumHeight(600)
         self.qtbl_readings.setFixedWidth(180)
-        self.qtbl_readings.setColumnWidth(0, 100)
+        self.qtbl_readings.setColumnWidth(0, 110)
 
         grid.addWidget(self.qtbl_readings, 0, 2, i, 1)
 
