@@ -4,7 +4,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "15-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.3"
 # pylint: disable=bare-except
 
 # Note: The `connection_lost` mechanism is not implemented on purpose
@@ -18,7 +18,7 @@ from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
 from dvg_debug_functions import ANSI, dprint
-from dvg_utils.dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY
+from dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY
 
 from dvg_devices.Keysight_N8700_protocol_SCPI import Keysight_N8700
 from dvg_devices.Keysight_N8700_qdev import Keysight_N8700_qdev
