@@ -7,7 +7,7 @@ __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
 __date__ = "07-07-2020"
-__version__ = "0.1.0"
+__version__ = "0.2.3"
 # pylint: disable=bare-except
 
 import sys
@@ -15,7 +15,7 @@ import sys
 from PyQt5 import QtCore, QtGui
 from PyQt5 import QtWidgets as QtWid
 
-from dvg_utils.dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY
+from dvg_pyqt_controls import SS_TEXTBOX_READ_ONLY
 
 from dvg_devices.Picotech_PT104_protocol_UDP import Picotech_PT104
 from dvg_devices.Picotech_PT104_qdev import Picotech_PT104_qdev
